summaryrefslogtreecommitdiff
path: root/django/db/backends/__init__.py
diff options
context:
space:
mode:
authorClaude Paroz <claude@2xlibre.net>2014-09-26 08:43:50 +0200
committerClaude Paroz <claude@2xlibre.net>2014-09-26 20:03:44 +0200
commitdbdae3a75512bddbf0b75ea6354fb3fc4bdb53cf (patch)
tree0549f86a215a0a04703ed47ee8ec082d87f34cda /django/db/backends/__init__.py
parent45840927d3516770be2654422e752357d5c063a5 (diff)
Fixed #22738 -- Abstracted boolean field type introspection
Thanks maxi for the report, Shai Berger for his help with the patch and Tim Graham for the review.
Diffstat (limited to 'django/db/backends/__init__.py')
-rw-r--r--django/db/backends/__init__.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/django/db/backends/__init__.py b/django/db/backends/__init__.py
index 9873d9cba6..8bdf6eed3c 100644
--- a/django/db/backends/__init__.py
+++ b/django/db/backends/__init__.py
@@ -614,8 +614,8 @@ class BaseDatabaseFeatures(object):
# Can the backend introspect an BinaryField, instead of an TextField?
can_introspect_binary_field = True
- # Can the backend introspect an BooleanField, instead of an IntegerField?
- can_introspect_boolean_field = True
+ # What is the type returned when the backend introspect a BooleanField?
+ introspected_boolean_field_type = 'BooleanField'
# Can the backend introspect an DecimalField, instead of an FloatField?
can_introspect_decimal_field = True